# Installing the Python Interface

```{note}
The installation of the standalone Monochrome application is **not** required, as the Python library includes all necessary files.
```

Run the following command to install Monochrome with the included Python library:

```bash
python -m pip install monochrome
```

On Windows you might need to run
```bash
py -m pip install monochrome
```

Run
```bash
python -m monochrome
```
to start the viewer in standalone mode.

See the [tutorial](tutorial) for a quick introduction to the Python library.
